@@ -79,6 +79,15 @@ class Word:
     def __repr__(self):
         return self.__str__()
 
+    def copy(self):
+        return Word(
+            word=self.word,
+            start_time_millis=self.start_time*1000,
+            end_time_millis=self.end_time*1000,
+            speaker=self.speaker,
+            confidence=self.confidence
+        )
+
 
 class TimestampedTranscriptionPacket(TranscriptionPacket):
     """
@@ -124,3 +133,11 @@ class SpacedLogitsDataPacket(LogitsDataPacket):
 
     def __str__(self):
         return f'{{"spaces": {str(self.spaces)}, {super().__str__()}}}'
+
+
+class ProcessedTranscriptionPacket(TimestampedTranscriptionPacket):
+    def __init__(self, processed_words: List[Word], raw_transcription_packet: TimestampedTranscriptionPacket):
+        super().__init__(words=raw_transcription_packet.words,
+                         headers=raw_transcription_packet.headers,
+                         transcript=' '.join([word.word for word in processed_words]))
+        self.processed_words = processed_words
